@@ -1,5 +1,5 @@
 package POE::Component::Client::Whois::TLDList;
-$POE::Component::Client::Whois::TLDList::VERSION = '1.34';
+$POE::Component::Client::Whois::TLDList::VERSION = '1.36';
 #ABSTRACT: Determine the applicable Whois server for a given Top-level domain (TLD).
 
 use strict;
@@ -1149,11 +1149,11 @@ sub tld {
   unless ( $lookup =~ /\./ ) {
     foreach my $tld ( sort keys %{ $self->{data} } ) {
 		  return @{ $self->{data}->{ $tld } }
-        if $lookup =~ /\Q$tld\E$/;
+        if $lookup =~ /\Q$tld\E$/i;
     }
   }
   else {
-    my $query = $lookup;
+    my $query = lc $lookup;
     while ( $query ) {
       if ( exists $self->{data}->{".$query"} ) {
         return @{ $self->{data}->{".$query"} };
@@ -1180,7 +1180,7 @@ POE::Component::Client::Whois::TLDList - Determine the applicable Whois server f
 
 =head1 VERSION
 
-version 1.34
+version 1.36
 
 =head1 SYNOPSIS
 
